# Custom X session to fit into Debian's way of doing things

# Load common environment variables
# shellcheck disable=SC1091
. "$HOME"/.profile

# Monitor and wallpaper setup is very machine-specific, and isn't versioned in
# here.  Neither xrandr(1) nor xwallpaper(1) have config files, so we fake it
# with xargs and looking for a file with argument tokens to read in
# XDG_CONFIG_HOME, which will almost always be:
#
# - ~/.config/xrandr/config
# - ~/.config/xwallpaper/config
#
xargs xrandr \
    < "${XDG_CONFIG_HOME:-"$HOME"/.config}"/xrandr/config
xargs xwallpaper \
    < "${XDG_CONFIG_HOME:-"$HOME"/.config}"/xwallpaper/config

# Set a few X user preferences:
#
# - No bell
# - No power management
# - Quick curved mouse acceleration
# - No screen saver
#
xset \
    b off \
    -dpms \
    mouse 5/2 0 \
    s off

# Start a couple of daemons if we can; it's OK if they don't exist, but log
# the failed attempt to start them to the errors file.
## compton: Display compositor
compton -b &
## dunst: Message display (libnotify)
dunst &

# Load all supplementary scripts in ~/.xsession.d
for sh in "$HOME"/.xsession.d/*.sh ; do
    [ -e "$sh" ] || continue
    . "$sh"
done
unset -v sh

# Start Debian's configured window manager now that everything's ready; at the
# time of writing, this is normally i3wm
exec x-window-manager
